@@ -299,8 +299,8 @@ impl<'a> RequestBuilder<'a> {
         let mut parts = std::mem::take(&mut self.uri).into_parts();
         let pq = parts.path_and_query.unwrap();
         let pq = PathAndQuery::from_str(match pq.query() {
-            Some(q) => format!("{}&{}={}", q, urlencoding::encode(k), urlencoding::encode(v)),
-            None => format!("?{}={}", urlencoding::encode(k), urlencoding::encode(v)),
+            Some(q) => format!("{}?{}&{}={}", pq.path(), q, urlencoding::encode(k), urlencoding::encode(v)),
+            None => format!("{}?{}={}", pq.path(), urlencoding::encode(k), urlencoding::encode(v)),
         }.as_str()).unwrap();
         parts.path_and_query = Some(pq);
         self.uri = Uri::from_parts(parts).unwrap();
@@ -310,7 +310,7 @@ impl<'a> RequestBuilder<'a> {
     pub fn bytes(mut self, bytes: &[u8]) -> Self {
         self.body = Some(Body::Bytes(bytes.to_vec()));
         self.headers.insert(
-            HeaderName::from_static("content-type"),
+            hyper::header::CONTENT_TYPE,
             HeaderValue::from_static("application/octet-stream")
         );
         self
@@ -319,7 +319,7 @@ impl<'a> RequestBuilder<'a> {
     pub fn text(mut self, text: &str) -> Self {
         self.body = Some(Body::Text(text.to_string()));
         self.headers.insert(
-            HeaderName::from_static("content-type"),
+            hyper::header::CONTENT_TYPE,
             HeaderValue::from_static("text/plain")
         );
         self
@@ -327,7 +327,7 @@ impl<'a> RequestBuilder<'a> {
 
     pub fn content_type(mut self, content_type: &str) -> Self {
         self.headers.insert(
-            HeaderName::from_static("Content-Type"),
+            hyper::header::CONTENT_TYPE,
             HeaderValue::from_str(content_type).unwrap(),
         );
         self
@@ -345,6 +345,7 @@ impl<'a> RequestBuilder<'a> {
 #[cfg(test)]
 mod tests {
     use super::*;
+    use http::Method;
 
     #[test]
     fn test_request_serialization_roundtrip() {
@@ -384,4 +385,14 @@ mod tests {
             .body(Body::Json(serde_json::to_value(&data).unwrap())).unwrap());
         assert_eq!(r1, r2);
     }
+
+    #[test]
+    fn test_push_query() {
+        let client = Client::new(None);
+        let mut r1 = RequestBuilder::new(&client, Method::GET, "http://example.com/foo/bar".parse().unwrap());
+        r1 = r1.push_query("a", "b");
+        assert_eq!(r1.uri.to_string(), "http://example.com/foo/bar?a=b");
+        r1 = r1.push_query("c", "d");
+        assert_eq!(r1.uri.to_string(), "http://example.com/foo/bar?a=b&c=d");
+    }
 }
\ No newline at end of file
